@@ -367,6 +367,20 @@ class PulseRawListAttribute(ComplexTypeAttribute):
     value: t.PulseRawList
 
 
+@dataclass
+class FlashInfoAttribute(ComplexTypeAttribute):
+    struct_format = t.FlashInfo.struct_format
+    attribute_id = 0xB7
+    value: t.FlashInfo
+
+
+@dataclass
+class BatteryDiagnosticsAttribute(ComplexTypeAttribute):
+    struct_format = t.BatteryDiagnostics.struct_format
+    attribute_id = 0xBB
+    value: t.BatteryDiagnostics
+
+
 @dataclass
 class ExecuteCommandResponseAfeReadAllRegsAttribute(Attribute):
     attribute_id = 0xA1
@@ -491,6 +505,10 @@ def decode_attribute(attribute_id, data: bytes) -> Attribute:
         return DiagnosticsAttribute.decode(data)
     if attribute_id == PulseRawListAttribute.attribute_id:
         return PulseRawListAttribute.decode(data)
+    if attribute_id == FlashInfoAttribute.attribute_id:
+        return FlashInfoAttribute.decode(data)
+    if attribute_id == BatteryDiagnosticsAttribute.attribute_id:
+        return BatteryDiagnosticsAttribute.decode(data)
     if attribute_id == LedsAttribute.attribute_id:
         return LedsAttribute.decode(data)
     raise LookupError(f"Unknown attribute type {attribute_id}")
