@@ -224,6 +224,14 @@ class GyroRaw(ComplexType):
     gyr_z: int = 0
 
 
+@dataclass
+class FlashInfo(ComplexType):
+    struct_format = "<BHH"
+    files: int = 0
+    used: int = 0
+    free: int = 0
+
+
 @dataclass
 class Recording(ComplexType):
     struct_format = ">BBBBBB"
@@ -248,6 +256,32 @@ class Diagnostics(ComplexType):
     avg_voltage: int
 
 
+@dataclass
+class BatteryDiagnostics(ComplexType):
+    struct_format = "<IIHHhhHHHH"
+    ttf: int  # s Time To Full
+    tte: int  # s Time To Empty
+    voltage: int  # mV *10 (0-6553.5 mV) Battery Voltage
+    avg_voltage: int  # mV *10 (0-6553.5 mV) Average Battery Voltage
+    current: int  # mA *100 (-327.68 - +327.67 mA) Battery Current
+    avg_current: int  # mA *100 (-327.68 - +327.67 mA) Average Battery Current
+    full_cap: int
+    # mAh *100 (0-655.35 mAh) Total battery capacity calculated after each cycle
+    rep_cap: int  # mAh *100 (0-655.35 mAh) Remaining capacity
+    repsoc: int  # % *100  (0-100.00 %) Reported State Of Charge (Combined and final result)
+    vfsoc: int  # % *100  (0-100.00 %) Voltage based fuelgauge State Of Charge
+
+    def to_str(self):
+        return (
+            f"ttf: {self.ttf}, tte: {self.tte}, voltage: {self.voltage} ({self.voltage * 10}mV), "
+            f"avg_voltage: {self.avg_voltage} ({self.avg_voltage * 10}mV), current: {self.current}"
+            f"({self.current * 100}mAh), avg_current: {self.avg_current} ({self.avg_current * 100}mAh), "
+            f"full_cap: {self.full_cap} ({self.full_cap * 100}mAh), rep_cap: {self.rep_cap} "
+            f"({self.rep_cap * 100}mAh), repsoc: {self.repsoc} ({self.repsoc * 100}%), "
+            f"vfsoc: {self.vfsoc} ({self.vfsoc * 100}%)"
+        )
+
+
 @dataclass
 class AfeSettings(ComplexType):
     struct_format = ">BBBBIIif"
